==> sablevm-classlib_1.1.8.orig.tar.gz: sablevm-classpath-1.1.8/vm/reference/gnu/classpath/VMSystemProperties.java <==
/* VMSystemProperties.java -- Allow the VM to set System properties.
   Copyright (C) 2004 Free Software Foundation

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.classpath;

import java.util.Properties;

class VMSystemProperties
{
    /**
     * Get the system properties. This is done here, instead of in System,
     * because of the bootstrap sequence. Note that the native code should
     * not try to use the Java I/O classes yet, as they rely on the properties
     * already existing. The only safe method to use to insert these default
     * system properties is {@link Properties#setProperty(String, String)}.
     *
     * <p>These properties MUST include:
     * <dl>
     * <dt>java.version         <dd>Java version number
     * <dt>java.vendor          <dd>Java vendor specific string
     * <dt>java.vendor.url      <dd>Java vendor URL
     * <dt>java.home            <dd>Java installation directory
     * <dt>java.vm.specification.version <dd>VM Spec version
     * <dt>java.vm.specification.vendor  <dd>VM Spec vendor
     * <dt>java.vm.specification.name    <dd>VM Spec name
     * <dt>java.vm.version      <dd>VM implementation version
     * <dt>java.vm.vendor       <dd>VM implementation vendor
     * <dt>java.vm.name         <dd>VM implementation name
     * <dt>java.specification.version    <dd>Java Runtime Environment version
     * <dt>java.specification.vendor     <dd>Java Runtime Environment vendor
     * <dt>java.specification.name       <dd>Java Runtime Environment name
     * <dt>java.class.version   <dd>Java class version number
     * <dt>java.class.path      <dd>Java classpath
     * <dt>java.library.path    <dd>Path for finding Java libraries
     * <dt>java.io.tmpdir       <dd>Default temp file path
     * <dt>java.compiler        <dd>Name of JIT to use
     * <dt>java.ext.dirs        <dd>Java extension path
     * <dt>os.name              <dd>Operating System Name
     * <dt>os.arch              <dd>Operating System Architecture
     * <dt>os.version           <dd>Operating System Version
     * <dt>file.separator       <dd>File separator ("/" on Unix)
     * <dt>path.separator       <dd>Path separator (":" on Unix)
     * <dt>line.separator       <dd>Line separator ("\n" on Unix)
     * <dt>user.name            <dd>User account name
     * <dt>user.home            <dd>User home directory
     * <dt>user.dir             <dd>User's current working directory
     * <dt>gnu.cpu.endian       <dd>"big" or "little"
     * </dl>
     *
     * @param p the Properties object to insert the system properties into
     */
    static void preInit(Properties p)
  {
    // set default values
    p.setProperty("java.version", "?");
    p.setProperty("java.vendor", "?");
    p.setProperty("java.vendor.url", "?");
    p.setProperty("java.home", "?");
    p.setProperty("java.vm.specification.version", "Second Edition");
    p.setProperty("java.vm.specification.vendor", "Addison Wesley");
    p.setProperty("java.vm.specification.name", "ISBN 0-201-43294-3");
    p.setProperty("java.vm.version", getSableVMVersion());
    p.setProperty("java.vm.vendor", "Etienne M. Gagnon and others");
    p.setProperty("java.vm.name", "SableVM");
    p.setProperty("java.specification.version", "?");
    p.setProperty("java.specification.vendor", "?");
    p.setProperty("java.specification.name", "?");
    p.setProperty("java.class.version", "?");
    p.setProperty("java.class.path", ".");
    p.setProperty("java.library.path", ".");
    p.setProperty("java.io.tmpdir", "/tmp");
    p.setProperty("java.compiler", "");
    p.setProperty("java.ext.dirs", "");
    p.setProperty("os.name", "?");
    p.setProperty("os.arch", "?");
    p.setProperty("os.version", "?");
    p.setProperty("file.separator", getFileSeparator());
    p.setProperty("path.separator", getPathSeparator());
    p.setProperty("line.separator", getLineSeparator());
    p.setProperty("user.name", getUserName());
    p.setProperty("user.home", getUserHome());
    p.setProperty("user.dir", getWorkDir());
    p.setProperty("sablevm.boot.class.path", getBootstrapClassPath());
    p.setProperty("sablevm.boot.library.path", getBootstrapLibraryPath());

    // We now set a non-standard property used by software like Ant
    // which depend on it.
    p.setProperty("sun.boot.class.path", getBootstrapClassPath());                                                                                                                                             
    p.setProperty("sun.boot.library.path", getBootstrapLibraryPath());                                                                                                                                         

  }

  private static native String getSableVMVersion();
  private static native String getFileSeparator();
  private static native String getPathSeparator();
  private static native String getLineSeparator();
  private static native String getUserName();
  private static native String getUserHome();
  private static native String getWorkDir();
  // currently used in Runtime, so we need package access
  static native String getBootstrapLibraryPath();
  private static native String getBootstrapClassPath();

  private static native int getPropertyCount();
  private static native String getProperty(int index);

    /**
     * Here you get a chance to overwrite some of the properties set by
     * the common SystemProperties code. For example, it might be
     * a good idea to process the properties specified on the command
     * line here.
     */
  static void postInit(Properties p)
  {
    // get command-line passed values. These values may override
    // default values above.
    int count = getPropertyCount();
    for (int i = 0; i < count; i++)
    {
      String property = getProperty(i);
      int equal_position = property.indexOf('=');
      String name = property.substring(0, equal_position);
      String value;

      if (equal_position < property.length())
      {
        value = property.substring(equal_position + 1);
      }
      else
      {
        value = "";
      }

      p.setProperty(name, value);
    }
  }
}

==> sablevm-classlib_1.11.3.orig.tar.gz: sablevm-classpath-1.11.3/vm/reference/gnu/classpath/VMSystemProperties.java <==
/* VMSystemProperties.java -- Allow the VM to set System properties.
   Copyright (C) 2004 Free Software Foundation

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.classpath;

import java.util.Properties;

class VMSystemProperties
{
    /**
     * Get the system properties. This is done here, instead of in System,
     * because of the bootstrap sequence. Note that the native code should
     * not try to use the Java I/O classes yet, as they rely on the properties
     * already existing. The only safe method to use to insert these default
     * system properties is {@link Properties#setProperty(String, String)}.
     *
     * <p>These properties MUST include:
     * <dl>
     * <dt>java.version         <dd>Java version number
     * <dt>java.vendor          <dd>Java vendor specific string
     * <dt>java.vendor.url      <dd>Java vendor URL
     * <dt>java.home            <dd>Java installation directory
     * <dt>java.vm.specification.version <dd>VM Spec version
     * <dt>java.vm.specification.vendor  <dd>VM Spec vendor
     * <dt>java.vm.specification.name    <dd>VM Spec name
     * <dt>java.vm.version      <dd>VM implementation version
     * <dt>java.vm.vendor       <dd>VM implementation vendor
     * <dt>java.vm.name         <dd>VM implementation name
     * <dt>java.specification.version    <dd>Java Runtime Environment version
     * <dt>java.specification.vendor     <dd>Java Runtime Environment vendor
     * <dt>java.specification.name       <dd>Java Runtime Environment name
     * <dt>java.class.version   <dd>Java class version number
     * <dt>java.class.path      <dd>Java classpath
     * <dt>java.library.path    <dd>Path for finding Java libraries
     * <dt>java.io.tmpdir       <dd>Default temp file path
     * <dt>java.compiler        <dd>Name of JIT to use
     * <dt>java.ext.dirs        <dd>Java extension path
     * <dt>os.name              <dd>Operating System Name
     * <dt>os.arch              <dd>Operating System Architecture
     * <dt>os.version           <dd>Operating System Version
     * <dt>file.separator       <dd>File separator ("/" on Unix)
     * <dt>path.separator       <dd>Path separator (":" on Unix)
     * <dt>line.separator       <dd>Line separator ("\n" on Unix)
     * <dt>user.name            <dd>User account name
     * <dt>user.home            <dd>User home directory
     * <dt>user.dir             <dd>User's current working directory
     * <dt>gnu.cpu.endian       <dd>"big" or "little"
     * </dl>
     *
     * @param p the Properties object to insert the system properties into
     */
    static void preInit(Properties p)
  {
    // set default values
    p.setProperty("java.version", "?");
    p.setProperty("java.vendor", "?");
    p.setProperty("java.vendor.url", "?");
    p.setProperty("java.home", "?");
    p.setProperty("java.vm.specification.version", "Second Edition");
    p.setProperty("java.vm.specification.vendor", "Addison Wesley");
    p.setProperty("java.vm.specification.name", "ISBN 0-201-43294-3");
    p.setProperty("java.vm.version", getSableVMVersion());
    p.setProperty("java.vm.vendor", "Etienne M. Gagnon and others");
    p.setProperty("java.vm.name", "SableVM");
    p.setProperty("java.specification.version", "?");
    p.setProperty("java.specification.vendor", "?");
    p.setProperty("java.specification.name", "?");
    p.setProperty("java.class.version", "?");
    p.setProperty("java.class.path", ".");
    p.setProperty("java.library.path", ".");
    p.setProperty("java.io.tmpdir", "/tmp");
    p.setProperty("java.compiler", "");
    p.setProperty("java.ext.dirs", "");
    p.setProperty("os.name", getOSName());
    p.setProperty("os.arch", getOSArch());
    p.setProperty("os.version", getOSVersion());
    p.setProperty("file.separator", getFileSeparator());
    p.setProperty("path.separator", getPathSeparator());
    p.setProperty("line.separator", getLineSeparator());
    p.setProperty("user.name", getUserName());
    p.setProperty("user.home", getUserHome());
    p.setProperty("user.dir", getWorkDir());
    p.setProperty("gnu.cpu.endian", isBigEndian() ? "big" : "little");
    p.setProperty("sablevm.boot.class.path", getBootstrapClassPath());
    p.setProperty("sablevm.boot.library.path", getBootstrapLibraryPath());

    // We now set a non-standard property used by software like Ant
    // which depend on it.
    p.setProperty("sun.boot.class.path", getBootstrapClassPath());                                                                                                                                             
    p.setProperty("sun.boot.library.path", getBootstrapLibraryPath());                                                                                                                                         

  }

  private static native String getSableVMVersion();
  private static native String getOSName();
  private static native String getOSArch();
  private static native String getOSVersion();
  private static native String getFileSeparator();
  private static native String getPathSeparator();
  private static native String getLineSeparator();
  private static native String getUserName();
  private static native String getUserHome();
  private static native String getWorkDir();
  private static native boolean isBigEndian();
  private static native String getBootstrapLibraryPath();
  private static native String getBootstrapClassPath();

  private static native int getPropertyCount();
  private static native String getProperty(int index);

    /**
     * Here you get a chance to overwrite some of the properties set by
     * the common SystemProperties code. For example, it might be
     * a good idea to process the properties specified on the command
     * line here.
     */
  static void postInit(Properties p)
  {
    // get command-line passed values. These values may override
    // default values above.
    int count = getPropertyCount();
    for (int i = 0; i < count; i++)
    {
      String property = getProperty(i);
      int equal_position = property.indexOf('=');
      String name = property.substring(0, equal_position);
      String value;

      if (equal_position < property.length())
      {
        value = property.substring(equal_position + 1);
      }
      else
      {
        value = "";
      }

      p.setProperty(name, value);
    }
  }
}
